Grid

Struct Grid 

pub struct Grid<Data: Copy> { /* private fields */ }

Implementations

Source

impl<Data: Copy> Grid<Data>

pub fn with_cell_count( x: Range<f64>, y: Range<f64>, cell_count: (usize, usize), ) -> Grid<Data>

Arguments
  • x: min_x..max_x defines the area in wich data can be inserted
  • y: min_y..max_y defines the area in wich data can be inserted
  • cell_count: (count_x, count_y) defines how many cell should be present
pub fn cell(&self, indexes: (usize, usize)) -> &Vec<((f64, f64), Data)>

Arguments
  • indexes: (x,y) cord of the cell

returns: &Vec<((f64, f64), Data), Global> the data stored in the cell

pub fn cell_count(&self) -> (usize, usize)

Arguments

returns: (usize, usize) the defined cell_count

pub fn cell_size(&self) -> (f64, f64)

Arguments

returns: (f64, f64) width and height of each cell