QuadTree

Struct QuadTree 

pub struct QuadTree<Data: Copy> { /* private fields */ }

Implementations

Source

impl<Data: Copy> QuadTree<Data>

pub fn with_capacity( x: Range<f64>, y: Range<f64>, capacity: u16, ) -> QuadTree<Data>

Arguments
  • x: min_x..max_x defines the area in wich data can be inserted
  • y: min_y..max_y defines the area in wich data can be inserted
  • capacity: capacity of each TreeNode
pub fn node(&self) -> &QuadTreeNode<Data>

Arguments

returns : &QuadTreeNode the root node of the QuadTree