pub struct QuadTree<Data: Copy> { /* private fields */ }Implementations
Sourceimpl<Data: Copy> QuadTree<Data>
impl<Data: Copy> QuadTree<Data>
Sourcepub fn with_capacity(
x: Range<f64>,
y: Range<f64>,
capacity: u16,
) -> QuadTree<Data>
pub fn with_capacity( x: Range<f64>, y: Range<f64>, capacity: u16, ) -> QuadTree<Data>
Arguments
x: min_x..max_x defines the area in wich data can be insertedy: min_y..max_y defines the area in wich data can be insertedcapacity: capacity of each TreeNode
Sourcepub fn node(&self) -> &QuadTreeNode<Data>
pub fn node(&self) -> &QuadTreeNode<Data>
Arguments
returns : &QuadTreeNode the root node of the QuadTree